=================
Smart Meter Texas
=================


.. image:: https://img.shields.io/pypi/v/smart_meter_texas.svg
        :target: https://pypi.python.org/pypi/smart_meter_texas

.. image:: https://img.shields.io/travis/grahamwetzler/smart_meter_texas.svg
        :target: https://travis-ci.com/grahamwetzler/smart_meter_texas

.. image:: https://readthedocs.org/projects/smart-meter-texas/badge/?version=latest
        :target: https://smart-meter-texas.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Package to connect to and retrieve data from the unoffical Smart Meter Texas API


* Free software: MIT license
* Documentation: https://smart-meter-texas.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
